Learn R Programming

monolix2rx (version 0.0.6)

autoplot.monolix2rx: Autoplot monolix2rx object

Description

Autoplot monolix2rx object

Usage

# S3 method for monolix2rx
autoplot(
  object,
  ...,
  ncol = 3,
  nrow = 3,
  log = "",
  xlab = "Time",
  ylab = "Predictions",
  page = FALSE
)

Value

a ggplot2 object

Arguments

object

an object, whose class will determine the behaviour of autoplot

...

ignored parameters for monolix2rx objects

nrow, ncol

Number of rows and columns

log

Should "" (neither x nor y), "x", "y", or "xy" (or "yx") be log-scale?

xlab, ylab

The x and y axis labels

page

number of page(s) for the individual plots, by default (FALSE) no pages are print; You can use TRUE for all pages to print, or list which pages you want to print